@@ -12,8 +12,8 @@ sudo -E kubectl get deployments
 
 if [[ "$KUBE" == "minikube" ]]; then
   echo ::group::METRICS
-  sudo -E kubectl top pods
-  sudo -E kubectl describe node minikube
+  sudo -E kubectl top pods || true
+  sudo -E kubectl describe node minikube || true
   echo ::endgroup::
 fi
 
@@ -36,3 +36,7 @@ echo ::endgroup::
 echo ::group::PULP_WEB_LOGS
 sudo -E kubectl logs -l app.kubernetes.io/name=nginx --tail=10000
 echo ::endgroup::
+
+echo ::group::POSTGRES
+sudo -E kubectl logs -l app.kubernetes.io/name=postgres --tail=10000
+echo ::endgroup::
